﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Globalization;
using FreeImageAPI;
using FreeImageAPI.Metadata;

namespace Imagenator
{
	class ImageInfo
	{
		public DateTime Timestamp { get; private set; }
		public int Number { get; private set; }
		public string Filename { get; private set; }

		public ImageInfo(DateTime timestamp, int number, string filename)
		{
			this.Timestamp = timestamp;
			this.Number = number;
			this.Filename = filename;
		}

		public static ImageInfo GetInfo(string path, int number)
		{
			using (FreeImageBitmap image = new FreeImageBitmap(path))
			{
				ImageInfo imageInfo = ImageInfo.GetInfo(image, number, path);
				if (imageInfo != null)
					return imageInfo;
			}
			return new ImageInfo(File.GetCreationTime(path), number, path);
		}

		public static ImageInfo GetInfo(FreeImageBitmap image, int number, string path)
		{
			ImageMetadata metadata = image.Metadata;
			metadata.HideEmptyModels = true;

			foreach (MetadataModel mModel in metadata.List)
			{
				if (mModel.Model != FREE_IMAGE_MDMODEL.FIMD_EXIF_EXIF)
					continue;

				if (mModel.TagExists("DateTimeOriginal") == false)
					continue;

				MetadataTag tag = mModel.GetTag("DateTimeOriginal");
				string val = ((string)tag.Value).Substring(0, 19);
				DateTime timestamp;
				if (DateTime.TryParseExact(val, "yyyy:MM:dd HH:mm:ss", DateTimeFormatInfo.InvariantInfo, DateTimeStyles.None, out timestamp) == true)
					return new ImageInfo(timestamp, number, path);
			}
			return null;
		}
	}
}
